#!/usr/bin/env python
# coding: utf-8

# # Chapter 1: Python Basics

# ## Understanding expressions and assignments

# In[ ]:


2*3.14159*1.496e8/3.156e7


# In[ ]:


radius = 1.496e8 # orbital radius in km
period = 3.156e7 # orbital period in s

# calculate orbital velocity
velocity = 2*3.14159*radius/period


# In[ ]:


print(velocity)


# In[ ]:


print("orbital velocity =", velocity, "km/s")


# In[ ]:


print("orbital velocity = {:5.2f} km/s".format(velocity))


# In[ ]:


radius = 10*radius
print("new orbital radius = {:.3e} km".format(radius))


# In[ ]:


# use Kepler's third law to calculate period in s from radius in km
period = 2*3.14159 * (6.674e-11*1.989e30)**(-1/2) *          (1e3*radius)**(3/2) 
# print period in yr
print("new orbital period = {:.1f} yr".format(period/3.156e7))

velocity = 2*3.14159*radius/period
print("new orbital velocity = {:.2f} km/s".format(velocity))


# ## Control structures

# ### Arithmetic series

# In[ ]:


sum = 0 # initialization
n = 100 # number of iterations

for k in range(1,n+1): # k running from 1 to n
    sum = sum + k      # iteration of sum
    #print(k,sum)
    
print("Sum =", sum)


# In[ ]:


# Gauss formula
print("Sum =", int(n*(n+1)/2))


# ### Fibonacci numbers

# In[ ]:


# how many numbers to compute
n_max = 10 

# initialize variables
F_prev = 0 # 0. number 
F = 1      # 1. number

# compute sequence of Fibonacci numbers
for n in range(1,n_max+1):
    #print("{:d}. Fibonacci number = {:d}".format(n,F))
    print(f"{n:d}. Fibonacci number = {F:d}")

    # next number is sum of F and the previous number
    F_next = F + F_prev
    #print(n, F_prev, F, F_next)
    
    # prepare next iteration
    F_prev = F # first reset F_prev
    F = F_next # then assign next number to F


# In[ ]:


# initialize variables
F_prev = 0 # 0. number 
n,F = 1,1  # 1. number

# compute sequence of Fibonacci numbers smaller than 1000
while F < 1000:
    print("{:d}. Fibonacci number = {:d}".format(n,F))
    
    # next number is sum of F and the previous number
    F_next = F + F_prev
    
    # prepare next iteration
    #F_prev = F # first reset F_prev
    #F = F_next # then assign next number to F
    F_prev,F = F,F_next
    n += 1     # increment counter


# In[ ]:


# initialize variables
F_prev = 0 # 0. number 
F = 1      # 1. number
n_even = 0 
n_odd = 0

# compute sequence of Fibonacci numbers smaller than 1000
while F < 1000: 
    # next number is sum of F and the previous number
    F_next = F + F_prev
    
    # prepare next iteration
    F_prev = F # first reset F_prev
    F = F_next # then assign next number to F
    
    # test if F is even (divisible by two) or odd
    if F%2 == 0:
        n_even += 1
    else:
        n_odd += 1
        
print("Found {0:d} even and {1:d} odd Fibonacci numbers".      format(n_even,n_odd))


# ## Working with modules and objects

# ### SciPy constants

# For more information about constants, see [docs.scipy.org/doc/scipy/reference/constants.html](https://docs.scipy.org/doc/scipy/reference/constants.html).

# In[ ]:


import scipy.constants

scipy.constants.gravitational_constant


# In[ ]:


import scipy.constants as const


# In[ ]:


dir(const)


# In[ ]:


# gravitational constant
const.G


# There is also a dictionary of physical constants:

# In[ ]:


from scipy.constants import physical_constants

print(physical_constants['Newtonian constant of gravitation'])


# ### Orbital velocity

# In[ ]:


from math import pi,sqrt
from astropy.constants import M_sun
from scipy.constants import G,au,year

print("1 au =", au, "m")
print("1 yr =", year, "s")

radius = 10*au
print("\nradial distance = {:.1f} au".format(radius/au))

# Kepler's third law 
period = 2*pi * sqrt(radius**3/(G*M_sun.value))
print("orbital period = {:.4f} yr".format(period/year))

velocity = 2*pi * radius/period # velocity in m/s
print("orbital velocity = {:.2f} km/s".format(1e-3*velocity))


# In[ ]:


print(M_sun)


# See also [docs.astropy.org/en/stable/constants/](https://docs.astropy.org/en/stable/constants/).

# In[ ]:




